@@ -8,7 +8,7 @@ from pathlib import PurePath
 
 import yaml
 
-__version__ = '0.3.4'
+__version__ = '0.3.5'
 version = __version__
 __edition__ = 'Community'
 edition = __edition__
@@ -97,3 +97,13 @@ class Data:
         OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
         """.format(years, company)
     ).strip()
+
+    @classmethod
+    def get_dependency(cls):
+        dependencies = dict(
+            pyyaml=dict(
+                package=cls.pyyaml_text,
+                url=cls.pyyaml_link
+            )
+        )
+        return dependencies
